;; Generated package description from modus-themes.el  -*- no-byte-compile: t -*-
(define-package "modus-themes" "4.4.0" "Elegant, highly legible and customizable themes" '((emacs "27.1")) :commit "a082d7739f627523c6d9098c869cf143fa60b014" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("faces" "theme" "accessibility") :url "https://github.com/protesilaos/modus-themes")
